From 705b9978ed914aba87e5a5191a1d0acacaf70a81 Mon Sep 17 00:00:00 2001
From: Alexandre Rostovtsev <tetromino@gentoo.org>
Date: Wed, 1 Feb 2012 05:51:20 -0500
Subject: [PATCH] gentoo: provide net and use inactive status when not
 connected

The status will be reset to started via a dispatcher script on up/down
events. See https://bugs.gentoo.org/show_bug.cgi?id=252137
---
 initscript/Gentoo/NetworkManager.in |   26 +++++++++++++++++++++++++-
 1 files changed, 25 insertions(+), 1 deletions(-)

diff --git a/initscript/Gentoo/NetworkManager.in b/initscript/Gentoo/NetworkManager.in
index 7db410b..1960795 100755
--- a/initscript/Gentoo/NetworkManager.in
+++ b/initscript/Gentoo/NetworkManager.in
@@ -3,18 +3,42 @@
 # Distributed under the terms of the GNU General Purpose License v2
 # $Header: /var/cvsroot/gentoo-x86/net-misc/networkmanager/files/networkmanager-0.9.2.0-init-provide-net-r1.patch,v 1.2 2012/02/21 23:19:19 tetromino Exp $
 
+description="NetworkManager daemon. The service is marked as started only \
+when a network connection is established."
+
 depend() {
    need dbus
+   provide net
 }
 
 start() {
+   # If we are re-called by a dispatcher event, we want to mark the service
+   # as started without starting the daemon again
+   yesno "${IN_BACKGROUND}" && return 0
+
+   [ -z "${INACTIVE_TIMEOUT}" ] && INACTIVE_TIMEOUT="1"
+
    ebegin "Starting NetworkManager"
    start-stop-daemon --start --quiet --pidfile /var/run/NetworkManager.pid \
       --exec /usr/sbin/NetworkManager -- --pid-file /var/run/NetworkManager.pid
-   eend $?
+   local _retval=$?
+   eend "${_retval}"
+   if [ "x${_retval}" = 'x0' ] && ! nm-online -t "${INACTIVE_TIMEOUT}"; then
+      einfo "Marking NetworkManager as inactive. It will automatically be marked"
+      einfo "as started after a network connection has been established."
+      mark_service_inactive
+   fi
+   return "${_retval}"
 }
 
 stop() {
+   # If we are re-called by a dispatcher event, we want to mark the service
+   # as inactive without stopping the daemon
+   if yesno "${IN_BACKGROUND}"; then
+      mark_service_inactive "${SVCNAME}"
+      return 0
+   fi
+
    ebegin "Stopping NetworkManager"
    start-stop-daemon --stop --quiet --pidfile /var/run/NetworkManager.pid
    eend $?
-- 
1.7.8.4

